
function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var crypto = _interopDefault(require('isomorphic-webcrypto'));
var algos = require('jose-algorithms');

function generateKey(alg, ref) {
    if ( ref === void 0 ) ref = {};
    var modulusLength = ref.modulusLength; if ( modulusLength === void 0 ) modulusLength = 2048;
    var publicExponent = ref.publicExponent; if ( publicExponent === void 0 ) publicExponent = new Uint8Array([0x01,
    0x00,0x01]);
    var usages = ref.usages; if ( usages === void 0 ) usages = ['sign','verify'];
    var extractable = ref.extractable; if ( extractable === void 0 ) extractable = true;

    if (!algos[alg]) 
        { throw new Error(("alg must be one of " + (Object.keys(algos)))); }
    var algo = Object.assign({}, algos[alg]);
    if (algo.name === 'RSASSA-PKCS1-v1_5') {
        algo.modulusLength = modulusLength;
        algo.publicExponent = publicExponent;
    }
    if (algo.name === 'ECDSA') {
        delete algo.hash;
    }
    return crypto.subtle.generateKey(algo, extractable, usages).then(function (keys) {
        if (!keys.publicKey) {
            return {
                sharedKey: keys
            };
        }
        return keys;
    }).catch(function (e) {
        throw new Error(("couldn't generate key: " + (e.message)));
    });
}

function importKey(json, ref) {
    if ( ref === void 0 ) ref = {};
    var alg = ref.alg; if ( alg === void 0 ) alg = null;
    var extractable = ref.extractable; if ( extractable === void 0 ) extractable = true;
    var usages = ref.usages; if ( usages === void 0 ) usages = null;

    if (!json) 
        { throw new Error('jwk must be an object'); }
    alg = alg || json.alg;
    if (!algos[alg]) 
        { throw new Error(("alg must be one of " + (Object.keys(algos)))); }
    var algo = Object.assign({}, algos[alg]);
    if (json.kty === 'EC') {
        algo.namedCurve = json.crv;
        delete algo.hash;
    }
    if (typeof window !== 'undefined' && window.msCrypto) {
        json = Object.assign({}, json);
        delete json.use;
    }
    if (!json.key_ops) {
        json = Object.assign({}, json);
        json.key_ops = json.d ? ['sign'] : ['verify'];
    }
    return crypto.subtle.importKey('jwk', json, algo, extractable, usages || json.key_ops).catch(function (e) {
        throw new Error(("couldn't import key: " + (e.message)));
    });
}

function exportKey(key) {
    return crypto.subtle.exportKey('jwk', key);
}

exports.generateKey = generateKey;
exports.importKey = importKey;
exports.exportKey = exportKey;
//# sourceMappingURL=jwk-lite.js.map
